==> ibus_1.5.10.orig.tar.gz: ibus-1.5.10/ui/gtk3/gen-notification-item.xml.c <==
const char * _notification_item = 
"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
"<node name=\"/StatusNotifierItem\">\n"
"        <interface name=\"org.kde.StatusNotifierItem\">\n"
"\n"
"<!-- Properties -->\n"
"                <property name=\"Id\" type=\"s\" access=\"read\" />\n"
"                <property name=\"Category\" type=\"s\" access=\"read\" />\n"
"                <property name=\"Status\" type=\"s\" access=\"read\" />\n"
"                <property name=\"IconName\" type=\"s\" access=\"read\" />\n"
"                <property name=\"IconAccessibleDesc\" type=\"s\" access=\"read\" />\n"
"                <property name=\"AttentionIconName\" type=\"s\" access=\"read\" />\n"
"                <property name=\"AttentionAccessibleDesc\" type=\"s\" access=\"read\" />\n"
"                <property name=\"Title\" type=\"s\" access=\"read\" />\n"
"                <!-- An additional path to add to the theme search path\n"
"                     to find the icons specified above. -->\n"
"                <property name=\"IconThemePath\" type=\"s\" access=\"read\" />\n"
"                <property name=\"Menu\" type=\"o\" access=\"read\" />\n"
"                <property name=\"XAyatanaLabel\" type=\"s\" access=\"read\" />\n"
"                <property name=\"XAyatanaLabelGuide\" type=\"s\" access=\"read\" />\n"
"                <property name=\"XAyatanaOrderingIndex\" type=\"u\" access=\"read\" />\n"
"\n"
"<!-- Methods -->\n"
"                <method name=\"Scroll\">\n"
"                        <arg type=\"i\" name=\"delta\" direction=\"in\" />\n"
"                        <arg type=\"s\" name=\"orientation\" direction=\"in\" />\n"
"                </method>\n"
"                <method name=\"SecondaryActivate\">\n"
"                        <arg type=\"i\" name=\"x\" direction=\"in\" />\n"
"                        <arg type=\"i\" name=\"y\" direction=\"in\" />\n"
"                </method>\n"
"                <method name=\"XAyatanaSecondaryActivate\">\n"
"                        <arg type=\"u\" name=\"timestamp\" direction=\"in\" />\n"
"                </method>\n"
"                <!-- Activate is missed in AppIndicator -->\n"
"                <method name=\"Activate\">\n"
"                        <arg type=\"i\" name=\"x\" direction=\"in\" />\n"
"                        <arg type=\"i\" name=\"y\" direction=\"in\" />\n"
"                </method>\n"
"                <method name=\"ContextMenu\">\n"
"                        <arg type=\"i\" name=\"x\" direction=\"in\"/>\n"
"                        <arg type=\"i\" name=\"y\" direction=\"in\"/>\n"
"                </method>\n"
"\n"
"<!-- Signals -->\n"
"                <signal name=\"NewIcon\">\n"
"                </signal>\n"
"                <signal name=\"NewIconThemePath\">\n"
"                        <arg type=\"s\" name=\"icon_theme_path\" direction=\"out\" />\n"
"                </signal>\n"
"                <signal name=\"NewAttentionIcon\">\n"
"                </signal>\n"
"                <signal name=\"NewStatus\">\n"
"                        <arg type=\"s\" name=\"status\" direction=\"out\" />\n"
"                </signal>\n"
"                <signal name=\"XAyatanaNewLabel\">\n"
"                        <arg type=\"s\" name=\"label\" direction=\"out\" />\n"
"                        <arg type=\"s\" name=\"guide\" direction=\"out\" />\n"
"                </signal>\n"
"                <signal name=\"NewTitle\">\n"
"                </signal>\n"
"\n"
"        </interface>\n"
"</node>\n"
;

==> ibus_1.5.22.orig.tar.gz: ibus-1.5.22/ui/gtk3/gen-notification-item.xml.c <==
const char * _notification_item = 
"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
"<node name=\"/StatusNotifierItem\">\n"
"        <interface name=\"org.kde.StatusNotifierItem\">\n"
"\n"
"<!-- Properties -->\n"
"                <property name=\"Id\" type=\"s\" access=\"read\" />\n"
"                <property name=\"Category\" type=\"s\" access=\"read\" />\n"
"                <property name=\"Status\" type=\"s\" access=\"read\" />\n"
"                <property name=\"IconName\" type=\"s\" access=\"read\" />\n"
"                <!-- IconPixmap is missed in AppIndicator\n"
"                     struct containing width, height and image data-->\n"
"                <property name=\"IconPixmap\" type=\"a(iiay)\" access=\"read\">\n"
"                        <annotation name=\"org.qtproject.QtDBus.QtTypeName\"\n"
"                                    value=\"KDbusImageVector\" />\n"
"                </property>\n"
"                <property name=\"IconAccessibleDesc\" type=\"s\" access=\"read\" />\n"
"                <property name=\"AttentionIconName\" type=\"s\" access=\"read\" />\n"
"                <property name=\"AttentionAccessibleDesc\" type=\"s\" access=\"read\" />\n"
"                <property name=\"Title\" type=\"s\" access=\"read\" />\n"
"                <!-- An additional path to add to the theme search path\n"
"                     to find the icons specified above. -->\n"
"                <property name=\"IconThemePath\" type=\"s\" access=\"read\" />\n"
"                <property name=\"Menu\" type=\"o\" access=\"read\" />\n"
"                <property name=\"XAyatanaLabel\" type=\"s\" access=\"read\" />\n"
"                <property name=\"XAyatanaLabelGuide\" type=\"s\" access=\"read\" />\n"
"                <property name=\"XAyatanaOrderingIndex\" type=\"u\" access=\"read\" />\n"
"\n"
"<!-- Methods -->\n"
"                <method name=\"Scroll\">\n"
"                        <arg type=\"i\" name=\"delta\" direction=\"in\" />\n"
"                        <arg type=\"s\" name=\"orientation\" direction=\"in\" />\n"
"                </method>\n"
"                <method name=\"SecondaryActivate\">\n"
"                        <arg type=\"i\" name=\"x\" direction=\"in\" />\n"
"                        <arg type=\"i\" name=\"y\" direction=\"in\" />\n"
"                </method>\n"
"                <method name=\"XAyatanaSecondaryActivate\">\n"
"                        <arg type=\"u\" name=\"timestamp\" direction=\"in\" />\n"
"                </method>\n"
"                <!-- Activate is missed in AppIndicator -->\n"
"                <method name=\"Activate\">\n"
"                        <arg type=\"i\" name=\"x\" direction=\"in\" />\n"
"                        <arg type=\"i\" name=\"y\" direction=\"in\" />\n"
"                </method>\n"
"                <method name=\"ContextMenu\">\n"
"                        <arg type=\"i\" name=\"x\" direction=\"in\"/>\n"
"                        <arg type=\"i\" name=\"y\" direction=\"in\"/>\n"
"                </method>\n"
"\n"
"<!-- Signals -->\n"
"                <signal name=\"NewIcon\">\n"
"                </signal>\n"
"                <signal name=\"NewIconThemePath\">\n"
"                        <arg type=\"s\" name=\"icon_theme_path\" direction=\"out\" />\n"
"                </signal>\n"
"                <signal name=\"NewAttentionIcon\">\n"
"                </signal>\n"
"                <signal name=\"NewStatus\">\n"
"                        <arg type=\"s\" name=\"status\" direction=\"out\" />\n"
"                </signal>\n"
"                <signal name=\"XAyatanaNewLabel\">\n"
"                        <arg type=\"s\" name=\"label\" direction=\"out\" />\n"
"                        <arg type=\"s\" name=\"guide\" direction=\"out\" />\n"
"                </signal>\n"
"                <signal name=\"NewTitle\">\n"
"                </signal>\n"
"\n"
"        </interface>\n"
"</node>\n"
;
